@@ -39,6 +39,7 @@ class MAXIMO_REST():
             :param mif: (``bool`` - optional) - True if maximo_mif to be used, False if maximo to be used in the URL (default value False)
             :param verbose: (``bool`` - optional) - Print internal messages if True (default value False)
             :param verify: (``bool`` - optional) - By pass SSL verification if True (default value True)
+            :param logger: (``Logger`` - optional) - Logger object used to export information to a log file (default value None)
 
             :returns: None
         """
@@ -96,7 +97,9 @@ class MAXIMO_REST():
         """
 
         if response.status_code in [200, 201, 304]:
-            if raw:
+            if response.status_code == 204:
+                return {'message': 'Record deleted successfully'}, response.status_code
+            elif raw:
                 return response.raw, response.status_code
             elif content:
                 return response.content, response.status_code
@@ -557,8 +560,8 @@ class MAXIMO_REST():
         """
             Execute query and get WOs.
 
-            :param select_fields: (``string`` - optional) - Fields included in the query (defaul value *)
-            :param where: (``string`` - optional) - Where condition to be included in the query (defaul value None)
+            :param select_fields: (``string`` - optional) - Fields included in the query (default value \*)
+            :param where: (``string`` - optional) - Where condition to be included in the query (default value None)
             :param orderBy: (``string`` - optional) - Field(s) to order data (default value None). + sign indicated ascending and - sign indicates descending
             :param gbcols: (``string`` - optional) - Group by columns condition to aggregate data (default value None). See https://www.imwuc.org/HigherLogic/System/DownloadDocumentFile.ashx?DocumentFileKey=f29fb7ba-5917-f2a9-e599-9161e5d14582
             :param oslc: (``bool`` - optional) - Defines whether to use oslc protocol or not (default value True)
@@ -577,8 +580,8 @@ class MAXIMO_REST():
         """
             Execute query and get Service Requests.
 
-            :param select_fields: (``string`` - optional) - Fields included in the query (defaul value *)
-            :param where: (``string`` - optional) - Where condition to be included in the query (defaul value None)
+            :param select_fields: (``string`` - optional) - Fields included in the query (default value \*)
+            :param where: (``string`` - optional) - Where condition to be included in the query (default value None)
             :param orderBy: (``string`` - optional) - Field(s) to order data (default value None). + sign indicated ascending and - sign indicates descending
             :param gbcols: (``string`` - optional) - Group by columns condition to aggregate data (default value None). See https://www.imwuc.org/HigherLogic/System/DownloadDocumentFile.ashx?DocumentFileKey=f29fb7ba-5917-f2a9-e599-9161e5d14582
             :param oslc: (``bool`` - optional) - Defines whether to use oslc protocol or not (default value True)
