@@ -46,6 +46,7 @@ class NEXUSIC_REST():
             :param timeout: (``int`` - optional) - Timeout threshold in seconds (default value None).
             :param verbose: (``bool`` - optional) - Print internal messages if True (default value False).
             :param verify: (``bool`` - optional) - By pass SSL verification if True (default value True).
+            :param logger: (``Logger`` - optional) - Logger object used to export information to a log file (default value None).
 
             :returns: None
         """
@@ -136,8 +137,10 @@ class NEXUSIC_REST():
             :return: (``tuple`` - dict or string, string) - response (json, raw or error string) and response status code.
         """
 
-        if response.status_code in [200]:
-            if raw:
+        if response.status_code in [200, 204]:
+            if response.status_code == 204:
+                return {'message': 'Record deleted successfully'}, response.status_code
+            elif raw:
                 return response.raw, response.status_code
             else:
                 return response.json(), response.status_code
@@ -166,7 +169,7 @@ class NEXUSIC_REST():
 
         uri = baseURI + '/security/login'
 
-        if self.logger != None and self.logger.level > 10:
+        if self.logger != None and self.logger.level == 10:
             utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
 
         res = requests.get(uri, headers={'Authorization': self.authentication_type + ' ' + self.key_64},
@@ -184,7 +187,7 @@ class NEXUSIC_REST():
 
         uri = baseURI + '/version' + '?hash=' + self.hash
 
-        if self.logger != None and self.logger.level > 10:
+        if self.logger != None and self.logger.level == 10:
             utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
 
         try:
@@ -239,13 +242,13 @@ class NEXUSIC_REST():
         uri = self.addParamToURI(uri, 'hash', self.hash)
 
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
 
             if xFilter != None:
                 headers = {'X-NEXUS-Filter': xFilter}
 
-                if self.logger != None and self.logger.level > 10:
+                if self.logger != None and self.logger.level == 10:
                     utils.print_log(headers, logger=self.logger, logLvl=logging.DEBUG)
 
                 res = requests.get(uri, headers=headers, verify=self.verify)
@@ -258,7 +261,7 @@ class NEXUSIC_REST():
             uri = uri.replace('startRow=' + str(startRow), 'startRow=' + str(pageSize))
             startRow = pageSize
             while len(result['rows']) < result['totalRows']:
-                if self.logger != None and self.logger.level > 10:
+                if self.logger != None and self.logger.level == 10:
                     utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
 
                 if xFilter != None:
@@ -297,7 +300,7 @@ class NEXUSIC_REST():
         uri = baseURI + '/bo/' + tableDBName + '/' + str(keyValue) + '/' + '?hash=' + self.hash
 
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
 
             res = requests.delete(uri, verify=self.verify)
@@ -326,7 +329,7 @@ class NEXUSIC_REST():
         uri = baseURI + '/bo/' + 'Repository_Data' + '/' + xFilter + '/' + '?hash=' + self.hash
 
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
 
             res = requests.get(uri, stream=True, verify=self.verify)
@@ -368,7 +371,7 @@ class NEXUSIC_REST():
         uri = baseURI + '/dashboard/' + str(rt_id) + '/' + '?hash=' + self.hash
 
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
 
             res = requests.get(uri, verify=self.verify)
@@ -408,7 +411,7 @@ class NEXUSIC_REST():
         uri += '?key=' + str(rt_id) + '&format=' + format + '&recipient=' + recipient + '&hash=' + self.hash
 
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
 
             res = requests.post(uri, verify=self.verify)
@@ -467,7 +470,7 @@ class NEXUSIC_REST():
                                 'parameters': parameters
                                 })
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
 
             res = requests.post(uri, data=json_dict)
@@ -509,7 +512,7 @@ class NEXUSIC_REST():
         uri = baseURI + '/jobStatus' + '?hash=' + self.hash + '&id=' + str(job_id)
 
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
 
             res = requests.get(uri)
@@ -550,7 +553,7 @@ class NEXUSIC_REST():
         uri = baseURI + '/jobContent' + '?hash=' + self.hash + '&id=' + str(job_id)
 
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
 
             res = requests.get(uri, stream=True)
@@ -580,7 +583,7 @@ class NEXUSIC_REST():
         uri += '/' + '?hash=' + self.hash
 
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
                 utils.print_log(str(parameters), logger=self.logger, logLvl=logging.DEBUG)
 
@@ -611,7 +614,7 @@ class NEXUSIC_REST():
         uri += '?hash=' + self.hash
 
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
                 utils.print_log(str(body), logger=self.logger, logLvl=logging.DEBUG)
 
@@ -642,7 +645,7 @@ class NEXUSIC_REST():
         uri += '?hash=' + self.hash
 
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(uri, logger=self.logger, logLvl=logging.DEBUG)
                 utils.print_log(str(body), logger=self.logger, logLvl=logging.DEBUG)
 
@@ -679,7 +682,7 @@ class NEXUSIC_REST():
         postblob_uri = self.icweb_uri + '/data/icweb.dll/postBlob' +'?hash=' + self.hash
 
         try:
-            if self.logger != None and self.logger.level > 10:
+            if self.logger != None and self.logger.level == 10:
                 utils.print_log(postblob_uri, logger=self.logger, logLvl=logging.DEBUG)
 
             # Execute post blob
@@ -1296,7 +1299,7 @@ class NEXUSIC_REST():
         :param mm_name: (``string``) - Multimedia name displayed in NEXUS IC
         :param filename: (``string``) - Name of the file to be imported
         :param binary_data: (``byte``) - The actual file as a byte variable
-        :param is_image: (``bool` - optional) - Define whether the file is an image or AVI file (default value True)
+        :param is_image: (``bool`` - optional) - Define whether the file is an image or AVI file (default value True)
         :param verbose: (``bool`` - optional) - Print internal messages if True (default value False)
 
         :return: (``tuple`` - dict or string, string) - response (json, raw or error string) and response status code
